=====
Usage
=====

General
-------

To use hirise-tools in a project::

    import pyrise

or

    import pyrise as ht

`products`
----------

    from pyrise import products

    obsid = products.OBS

